@@ -1,14 +1,16 @@
 
-#include <test.hpp>
+#include <buffer.hpp>
 
 #include <array>
+#include <sstream>
 
 #include "t/repeated_packed_fixed32/repeated_packed_fixed32_testcase.pb.h"
 
-TEST_CASE("write repeated packed fixed32 field and check with libprotobuf") {
+TEMPLATE_TEST_CASE("write repeated packed fixed32 field and check with libprotobuf", "",
+    buffer_test_string, buffer_test_vector, buffer_test_array, buffer_test_external) {
 
-    std::string buffer;
-    protozero::pbf_writer pw{buffer};
+    TestType buffer;
+    typename TestType::writer_type pw{buffer.buffer()};
 
     TestRepeatedPackedFixed32::Test msg;
 
@@ -21,7 +23,7 @@ TEST_CASE("write repeated packed fixed32 field and check with libprotobuf") {
         const std::array<uint32_t, 1> data = {{ 17UL }};
         pw.add_packed_fixed32(1, std::begin(data), std::end(data));
 
-        msg.ParseFromString(buffer);
+        msg.ParseFromArray(buffer.data(), buffer.size());
 
         REQUIRE(msg.i().size() == 1);
         REQUIRE(msg.i(0) == 17UL);
@@ -31,7 +33,7 @@ TEST_CASE("write repeated packed fixed32 field and check with libprotobuf") {
         const std::array<uint32_t, 4> data = {{ 17UL, 0UL, 1UL, std::numeric_limits<uint32_t>::max() }};
         pw.add_packed_fixed32(1, std::begin(data), std::end(data));
 
-        msg.ParseFromString(buffer);
+        msg.ParseFromArray(buffer.data(), buffer.size());
 
         REQUIRE(msg.i().size() == 4);
         REQUIRE(msg.i(0) == 17UL);
@@ -41,17 +43,18 @@ TEST_CASE("write repeated packed fixed32 field and check with libprotobuf") {
     }
 }
 
-TEST_CASE("write from different types of iterators and check with libprotobuf") {
+TEMPLATE_TEST_CASE("write from different types of iterators and check with libprotobuf", "",
+    buffer_test_string, buffer_test_vector, buffer_test_array, buffer_test_external) {
 
-    std::string buffer;
-    protozero::pbf_writer pw{buffer};
+    TestType buffer;
+    typename TestType::writer_type pw{buffer.buffer()};
 
     TestRepeatedPackedFixed32::Test msg;
 
     SECTION("from uint16_t") {
         const std::array<uint16_t, 5> data = {{ 1, 4, 9, 16, 25 }};
 
-        pw.add_packed_fixed<uint32_t>(1, std::begin(data), std::end(data));
+        pw.template add_packed_fixed<uint32_t>(1, std::begin(data), std::end(data));
     }
 
     SECTION("from string") {
@@ -61,10 +64,10 @@ TEST_CASE("write from different types of iterators and check with libprotobuf")
         std::istream_iterator<uint32_t> eod;
         std::istream_iterator<uint32_t> it(sdata);
 
-        pw.add_packed_fixed<uint32_t>(1, it, eod);
+        pw.template add_packed_fixed<uint32_t>(1, it, eod);
     }
 
-    msg.ParseFromString(buffer);
+    msg.ParseFromArray(buffer.data(), buffer.size());
 
     REQUIRE(msg.i().size() == 5);
     REQUIRE(msg.i(0) ==  1);
