@@ -64,61 +64,61 @@ TEST_CASE("next() should throw when illegal wire type is encountered") {
     const char buffer[1] = {1U << 3U | 7U};
 
     protozero::pbf_reader item{buffer, 1};
-    REQUIRE_THROWS_AS(item.next(), const protozero::unknown_pbf_wire_type_exception&);
+    REQUIRE_THROWS_AS(item.next(), protozero::unknown_pbf_wire_type_exception);
 }
 
 TEST_CASE("next() should throw when illegal tag 0 is encountered") {
     std::string data;
-    protozero::write_varint(std::back_inserter(data), 0U << 3U | 1U);
+    protozero::add_varint_to_buffer(&data, 0U << 3U | 1U);
     protozero::pbf_reader item{data};
-    REQUIRE_THROWS_AS(item.next(), const protozero::invalid_tag_exception&);
+    REQUIRE_THROWS_AS(item.next(), protozero::invalid_tag_exception);
 }
 
 TEST_CASE("next() should throw when illegal tag 19000 is encountered") {
     std::string data;
-    protozero::write_varint(std::back_inserter(data), 19000U << 3U | 1U);
+    protozero::add_varint_to_buffer(&data, 19000U << 3U | 1U);
     protozero::pbf_reader item{data};
-    REQUIRE_THROWS_AS(item.next(), const protozero::invalid_tag_exception&);
+    REQUIRE_THROWS_AS(item.next(), protozero::invalid_tag_exception);
 }
 
 TEST_CASE("next() should throw when illegal tag 19001 is encountered") {
     std::string data;
-    protozero::write_varint(std::back_inserter(data), 19001U << 3U | 1U);
+    protozero::add_varint_to_buffer(&data, 19001U << 3U | 1U);
     protozero::pbf_reader item{data};
-    REQUIRE_THROWS_AS(item.next(), const protozero::invalid_tag_exception&);
+    REQUIRE_THROWS_AS(item.next(), protozero::invalid_tag_exception);
 }
 
 TEST_CASE("next() should throw when illegal tag 19999 is encountered") {
     std::string data;
-    protozero::write_varint(std::back_inserter(data), 19999U << 3U | 1U);
+    protozero::add_varint_to_buffer(&data, 19999U << 3U | 1U);
     protozero::pbf_reader item{data};
-    REQUIRE_THROWS_AS(item.next(), const protozero::invalid_tag_exception&);
+    REQUIRE_THROWS_AS(item.next(), protozero::invalid_tag_exception);
 }
 
 TEST_CASE("next() works when legal tag 1 is encountered") {
     std::string data;
-    protozero::write_varint(std::back_inserter(data), 1U << 3U | 1U);
+    protozero::add_varint_to_buffer(&data, 1U << 3U | 1U);
     protozero::pbf_reader item{data};
     REQUIRE(item.next());
 }
 
 TEST_CASE("next() works when legal tag 18999 is encountered") {
     std::string data;
-    protozero::write_varint(std::back_inserter(data), 18999U << 3U | 1U);
+    protozero::add_varint_to_buffer(&data, 18999U << 3U | 1U);
     protozero::pbf_reader item{data};
     REQUIRE(item.next());
 }
 
 TEST_CASE("next() works when legal tag 20000 is encountered") {
     std::string data;
-    protozero::write_varint(std::back_inserter(data), 20000U << 3U | 1U);
+    protozero::add_varint_to_buffer(&data, 20000U << 3U | 1U);
     protozero::pbf_reader item{data};
     REQUIRE(item.next());
 }
 
 TEST_CASE("next() works when legal tag 1^29 - 1 is encountered") {
     std::string data;
-    protozero::write_varint(std::back_inserter(data), ((1UL << 29U) - 1U) << 3U | 1U);
+    protozero::add_varint_to_buffer(&data, ((1UL << 29U) - 1U) << 3U | 1U);
     protozero::pbf_reader item{data};
     REQUIRE(item.next());
 }
@@ -127,15 +127,15 @@ TEST_CASE("pbf_writer asserts on invalid tags") {
     std::string data;
     protozero::pbf_writer writer{data};
 
-    REQUIRE_THROWS_AS(writer.add_int32(0, 123), const assert_error&);
+    REQUIRE_THROWS_AS(writer.add_int32(0, 123), assert_error);
     writer.add_int32(1, 123);
     writer.add_int32(2, 123);
     writer.add_int32(18999, 123);
-    REQUIRE_THROWS_AS(writer.add_int32(19000, 123), const assert_error&);
-    REQUIRE_THROWS_AS(writer.add_int32(19001, 123), const assert_error&);
-    REQUIRE_THROWS_AS(writer.add_int32(19999, 123), const assert_error&);
+    REQUIRE_THROWS_AS(writer.add_int32(19000, 123), assert_error);
+    REQUIRE_THROWS_AS(writer.add_int32(19001, 123), assert_error);
+    REQUIRE_THROWS_AS(writer.add_int32(19999, 123), assert_error);
     writer.add_int32(20000, 123);
     writer.add_int32((1U << 29U) - 1U, 123);
-    REQUIRE_THROWS_AS(writer.add_int32(1U << 29U, 123), const assert_error&);
+    REQUIRE_THROWS_AS(writer.add_int32(1U << 29U, 123), assert_error);
 }
 
